@@ -29,6 +29,7 @@ class RecvFile {
 
 	Pal *pal;
 	char *msg;
+	uint32_t commandn;
 	uint32_t packetn;
 	GSList *filelist;
 	GtkTreeModel *file_model;
@@ -36,6 +37,11 @@ class RecvFile {
  private:
 	static void CellEditText(GtkCellRendererText * renderer, gchar * path,
 				 gchar * new_text, GtkTreeModel * model);
+	static void SelectItemChanged(GtkTreeSelection *selection,
+				      GtkWidget *chooser);
+	static void ChooserResetLabel(GtkWidget *chooser, GtkWidget *label);
+	static void ChooserResetModel(GtkWidget *chooser,
+				      GtkTreeSelection *selection);
 	static void AdditionRecvFile(GtkTreeModel * model);
 };
 
