@@ -12,8 +12,18 @@
 #ifndef SYS_H
 #define SYS_H
 
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
+/* <stdint.h> */
+#define __STDC_LIMIT_MACROS
+/* <inttypes.h> */
+#define __STDC_FORMAT_MACROS
+
 #include <stdio.h>
 #include <stdint.h>
+#include <inttypes.h>
 #include <stdlib.h>
 #include <pthread.h>
 #include <string.h>
@@ -31,6 +41,14 @@
 #include <dirent.h>
 #include <ftw.h>
 #include <signal.h>
+#include <sys/vfs.h>
+#include <pwd.h>
+#include <locale.h>
+#include <libintl.h>
 typedef void *pointer;
 
+#ifndef _
+#define _(string) gettext(string)
+#endif
+
 #endif
